@@ -3,13 +3,13 @@
 # Test the pop code
 #
 
-source $REG_DIR/scaffold
+source "$REG_DIR/scaffold"
 
 cmd setup_repo
 
 cmd guilt push --all
 
-cmd git log -p
+cmd list_files
 
 #
 # incremental pop by 1
@@ -18,10 +18,14 @@ guilt series | _tac | while read n ; do
 	cmd guilt pop
 
 	cmd list_files
-
-	cmd git log -p
 done
 
+#
+# pop when there is nothing to pop
+#
+
+shouldfail guilt pop
+
 #
 # push all
 #
@@ -35,8 +39,6 @@ guilt series | _tac | while read n ; do
 
 	cmd list_files
 
-	cmd git log -p
-
 	cmd guilt push --all
 done
 
@@ -47,8 +49,6 @@ guilt series | _tac | while read n ; do
 	cmd guilt pop $t
 
 	cmd list_files
-
-	cmd git log -p
 done
 
 #
@@ -61,13 +61,11 @@ for n in `_seq -2 $npatches`; do
 	if [ $n -gt 0 ]; then
 		cmd guilt pop -n $n
 	else
-		shouldfail guilt pop -n $n 2>&1
+		shouldfail guilt pop -n $n
 	fi
 
 	cmd list_files
 
-	cmd git log -p
-
 	cmd guilt push --all
 done
 
