@@ -3,7 +3,7 @@
 # Test the top code
 #
 
-source $REG_DIR/scaffold
+source "$REG_DIR/scaffold"
 
 cmd setup_repo
 
